==> bluedot_rest_framework-2.0.26.tar.gz: bluedot_rest_framework-2.0.26/bluedot_rest_framework/event/vote/views.py <==
from rest_framework.decorators import action
from rest_framework.response import Response
from rest_framework import status
from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
from bluedot_rest_framework.settings import api_settings
from django.utils.module_loading import import_string
from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler,jwt_get_openid_handler

EventVote = import_string(api_settings.EVENT['vote']['models'])
EventVoteSerializer = import_string(api_settings.EVENT['vote']['serializers'])
EventVoteUser = import_string(api_settings.EVENT['vote']['user_models'])
EventVoteUserSerializer = import_string(api_settings.EVENT['vote']['user_serializers'])

class EventVoteView(CustomModelViewSet):
    model_class = EventVote
    serializer_class = EventVoteSerializer
    pagination_class = None

    filterset_fields = {
        'title': ['contains'],
        '_type': ['exact'],
        'event_id': ['exact'],
    }

    def create(self, request, *args, **kwargs):
        event_id=self.request.data.get('event_id', None)
        queryset=self.model_class.objects.filter(event_id=event_id).first()
        if queryset:
            partial = kwargs.pop('partial', False)
            serializer = self.get_serializer(queryset, data=request.data, partial=partial)
            serializer.is_valid(raise_exception=True)
            self.perform_update(serializer)
            return Response(serializer.data)
        else:
            serializer = self.get_serializer(data=request.data)
            serializer.is_valid(raise_exception=True)
            self.perform_create(serializer)
            headers = self.get_success_headers(serializer.data)
            return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
            

    def list(self, request, *args, **kwargs):
        event_id = request.query_params.get('event_id', None)
        queryset = self.model_class.objects.filter(event_id=event_id).first()
        serializer = self.get_serializer(queryset)
        return Response(serializer.data)


class EventVoteUserView(CustomModelViewSet):
    model_class = EventVoteUser
    serializer_class = EventVoteUserSerializer

    filterset_fields = {
        'event_id': ['exact']
    }
 

    def list(self, request, *args, **kwargs):
        event_id = request.query_params.get('event_id', None)
        openid = jwt_get_openid_handler(request.auth)
        data = self.model_class.objects.filter(
            event_id=event_id, openid=openid).first()
        if data:
            serializer = self.get_serializer(data)
            return Response({'code': '1', 'data': serializer.data})
        else:
            return Response({'code': '0'})

    def perform_create(self, serializer):
        return user_perform_create(self.request.auth, serializer)

==> bluedot_rest_framework-2.0.37.tar.gz: bluedot_rest_framework-2.0.37/bluedot_rest_framework/event/vote/views.py <==
from rest_framework.decorators import action
from rest_framework.response import Response
from rest_framework import status
from bluedot_rest_framework import import_string
from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler, jwt_get_openid_handler

EventVote = import_string('EVENT.vote.models')
EventVoteSerializer = import_string('EVENT.vote.serializers')
EventVoteUser = import_string('EVENT.vote.user_models')
EventVoteUserSerializer = import_string('EVENT.vote.user_serializers')


class EventVoteView(CustomModelViewSet):
    model_class = EventVote
    serializer_class = EventVoteSerializer
    pagination_class = None

    filterset_fields = {
        'title': ['contains'],
        '_type': ['exact'],
        'event_id': ['exact'],
    }

    def create(self, request, *args, **kwargs):
        event_id = self.request.data.get('event_id', None)
        queryset = self.model_class.objects.filter(event_id=event_id).first()
        if queryset:
            partial = kwargs.pop('partial', False)
            serializer = self.get_serializer(
                queryset, data=request.data, partial=partial)
            serializer.is_valid(raise_exception=True)
            self.perform_update(serializer)
            return Response(serializer.data)
        else:
            serializer = self.get_serializer(data=request.data)
            serializer.is_valid(raise_exception=True)
            self.perform_create(serializer)
            headers = self.get_success_headers(serializer.data)
            return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)

    def list(self, request, *args, **kwargs):
        event_id = request.query_params.get('event_id', None)
        queryset = self.model_class.objects.filter(event_id=event_id).first()
        serializer = self.get_serializer(queryset)
        return Response(serializer.data)


class EventVoteUserView(CustomModelViewSet):
    model_class = EventVoteUser
    serializer_class = EventVoteUserSerializer

    filterset_fields = {
        'event_id': ['exact']
    }

    def list(self, request, *args, **kwargs):
        event_id = request.query_params.get('event_id', None)
        openid = jwt_get_openid_handler(request.auth)
        data = self.model_class.objects.filter(
            event_id=event_id, openid=openid).first()
        if data:
            serializer = self.get_serializer(data)
            return Response({'code': '1', 'data': serializer.data})
        else:
            return Response({'code': '0'})

    def perform_create(self, serializer):
        return user_perform_create(self.request.auth, serializer)
